@@ -11,7 +11,6 @@ import pygments
 import pygments.lexers
 import toml
 
-from .linenumbers import LineNumberBar
 from .schemeparser import _parse_scheme
 
 color_schemes_dir = Path(__file__).parent / "colorschemes"
@@ -31,24 +30,19 @@ class CodeView(tkinter.Text):
     ) -> None:
         self._frame = ttk.Frame(master)
         self._frame.grid_rowconfigure(0, weight=1)
-        self._frame.grid_columnconfigure(1, weight=1)
+        self._frame.grid_columnconfigure(0, weight=1)
 
         kwargs.setdefault("wrap", "none")
         kwargs.setdefault("font", ("monospace", 11))
 
         super().__init__(self._frame, **kwargs)
-        super().grid(row=0, column=2, sticky="nswe")
-
-        self._line_numbers = LineNumberBar(self._frame, self)
-        self._line_numbers.grid(row=0, column=0, rowspan=2, sticky="nswe")
-
-        ttk.Separator(self._frame, orient="vertical").grid(row=0, column=1, sticky="ns")
+        super().grid(row=0, column=0, sticky="nswe")
 
         self._hs = ttk.Scrollbar(self._frame, orient="horizontal", command=self.xview)
         self._vs = ttk.Scrollbar(self._frame, orient="vertical", command=self.yview)
 
-        self._hs.grid(row=1, column=2, sticky="we")
-        self._vs.grid(row=0, column=3, sticky="ns")
+        self._hs.grid(row=1, column=0, sticky="we")
+        self._vs.grid(row=0, column=1, sticky="ns")
 
         super().configure(
             xscrollcommand=self._hs.set,
@@ -95,19 +89,13 @@ class CodeView(tkinter.Text):
             raise e from None
 
         if command == "insert":
-            self.event_generate("<<Scroll>>")
-
             length = len(args[1].splitlines())
             if length == 1:
                 self._highlight()
             else:
                 self.after_idle(lambda: self._highlight_lines(length))
         elif command in {"replace", "delete"}:
-            self.event_generate("<<Scroll>>")
-
             self._highlight()
-        elif command in {"xview", "yview", "see"}:
-            self.event_generate("<<Scroll>>")
 
         return result
 
@@ -169,7 +157,10 @@ class CodeView(tkinter.Text):
     def _set_color_scheme(
         self, color_scheme: dict[str, dict[str, str | int]] | str | None
     ) -> None:
-        if color_scheme in self._builtin_color_schemes:
+        if (
+            isinstance(color_scheme, str)
+            and color_scheme in self._builtin_color_schemes
+        ):
             color_scheme = toml.load(color_schemes_dir / f"{color_scheme}.toml")
         elif color_scheme is None:
             color_scheme = toml.load(color_schemes_dir / "dracula.toml")
@@ -182,13 +173,11 @@ class CodeView(tkinter.Text):
         self.configure(**config)
         self._setup_tags(tags)
 
-        self.event_generate("<<ColorSchemeChanged>>")
         self.highlight_all()
 
     def _set_lexer(self, lexer: pygments.lexers.Lexer) -> None:
         self._lexer = lexer
 
-        self.event_generate("<<LexerChanged>>")
         self.highlight_all()
 
     def __setitem__(self, key: str, value) -> None:
